@@ -14,7 +14,7 @@ use constant {
     SCALE => 12, # Scale notes
 };
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 
 sub barycenter {
@@ -87,7 +87,7 @@ Music::Interval::Barycentric - Compute barycentric musical interval space
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -106,14 +106,18 @@ Barycentric chord analysis
 
 =head2 barycenter()
 
+ @barycenter = barycenter($n);
+
 Return the barycenter (the "central coordinate")  given an integer representing
 the number of notes in a chord.
 
 =head2 distance()
 
+ $d = distance($chord1, $chord2);
+
 Interval space distance metric between chords.
 
-* This is used by the orbit_distance() and evenness_index() functions.
+* This is used by the C<orbit_distance()> and C<evenness_index()> functions.
 
 =head2 orbit_distance()
 
@@ -124,14 +128,21 @@ for C<chord2>.
 
 =head2 forte_distance()
 
-TODO
+  $d = forte_distance($chord1, $chord2);
+
+Return the distance from C<chord1> to the minimum of the cyclic permutations and
+reverse cyclic permutations for C<chord2>.
 
 =head2 cyclic_permutation()
 
+ @cycles = cyclic_permutation(@intervals);
+
 Return the list of cyclic permutations of the given intervals.
 
 =head2 evenness_index()
 
+  $d = evenness_index($chord);
+
 Return a chord distance from the barycenter.
 
 =head1 SEE ALSO
